@@ -1,5 +1,3 @@
-from asyncio import sleep
-
 from vkbottle.exceptions import VKError
 from vkbottle.framework.blueprint.user import Blueprint
 
@@ -8,6 +6,7 @@ user = Blueprint(
 )
 
 
+# noinspection PyUnusedLocal
 @user.error_handler.error_handler(5)
 async def rps_handler(e: VKError):
     exit(1)
