@@ -66,6 +66,11 @@ def service_prefix(value: str):
         return value
 
 
+@validator
+def lower_str(value: str):
+    return value.lower()
+
+
 @validator
 def repeater_word(value: str):
     db = Database.get_current()
